@@ -1,5 +1,6 @@
 import React from 'react';
 import ReactMarkdown from 'react-markdown';
+import remarkGfm from 'remark-gfm';
 import styled from 'styled-components';
 import StyledEmptyPanel from '../common/EmptyPanel';
 import { faFolderOpen } from '@fortawesome/free-solid-svg-icons';
@@ -20,7 +21,7 @@ const WorkflowDocsPanel = ({
     {docs && Object.keys(docs).length !== 0 ? (
       <div className="docs-panel-contents markdown-body">
         {Object.values(docs).map(Item => (
-          <ReactMarkdown children={Item} />
+          <ReactMarkdown children={Item} remarkPlugins={[remarkGfm]} />
         ))}
       </div>
     ) : (
